@@ -89,6 +89,7 @@ from tendenci.apps.perms.decorators import superuser_required
 from tendenci.apps.base.utils import send_email_notification
 from tendenci.apps.profiles.models import Profile
 from tendenci.apps.site_settings.utils import get_setting
+from tendenci.apps.base.utils import escape_csv
 
 
 @is_enabled('corporate_memberships')
@@ -474,7 +475,8 @@ def corpmembership_edit(request, id,
 
     app_fields = app.fields.filter(display=True)
     if not is_superuser:
-        app_fields = app_fields.filter(admin_only=False)
+        if not (corp_membership.is_pending and has_perm(request.user, 'corporate_memberships.approve_corpmembership')):
+            app_fields = app_fields.filter(admin_only=False)
     if corp_membership.is_expired:
         # if it is expired, remove the expiration_dt field so they can
         # renew this corporate membership
@@ -541,15 +543,19 @@ def corpmembership_edit(request, id,
 
 
 @is_enabled('corporate_memberships')
-@staff_member_required
+@login_required
 def corpprofile_view(request, id, template="corporate_memberships/profiles/view.html"):
     """
-        view a corp profile - superuser only
+        view a corp profile - superuser or reps or users with view_corpprofile perms.
     """
-    if not request.user.is_superuser:
-        raise Http403
-
     corp_profile = get_object_or_404(CorpProfile, id=id)
+    if not request.user.is_superuser:
+        if not has_perm(request.user,
+                    'corporate_memberships.view_corpprofile',
+                    corp_profile):
+            if not corp_profile.is_rep(request.user):
+                raise Http403
+
     corp_membership = corp_profile.corp_membership
     reps = corp_profile.reps.all()
     memberships = MembershipDefault.objects.filter(
@@ -762,14 +768,16 @@ def corpmembership_search(request, my_corps_only=False,
         if my_corps_only or not allow_anonymous_search:
             raise Http403
     is_superuser = request.user.profile.is_superuser
+    has_approve_perm = has_perm(request.user, 'corporate_memberships.approve_corpmembership')
 
     # legacy pending url
     query = request.GET.get('q')
     if query == 'is_pending:true':
         pending_only = True
 
-    if pending_only and not is_superuser:
-        raise Http403
+    if pending_only:
+        if not has_approve_perm:
+            raise Http403
 
     # field names for search criteria choices
     names_list = ['name', 'address', 'city', 'state',
@@ -784,7 +792,7 @@ def corpmembership_search(request, my_corps_only=False,
     except:
         cp_id = 0
 
-    if pending_only and is_superuser:
+    if pending_only and has_approve_perm:
         # pending list only for admins
         q_obj = Q(status_detail__in=['pending', 'paid - pending approval'])
         corp_members = CorpMembership.objects.filter(q_obj)
@@ -932,8 +940,7 @@ def corpmembership_approve(request, id,
                 template="corporate_memberships/applications/approve.html"):
     corporate_membership = get_object_or_404(CorpMembership, id=id)
 
-    user_is_superuser = request.user.profile.is_superuser
-    if not user_is_superuser:
+    if not has_perm(request.user, 'corporate_memberships.approve_corpmembership', corporate_membership):
         raise Http403
 
     # if not in pending, go to view page
@@ -1730,6 +1737,8 @@ def corpmembership_export(request,
                             row_item_list[i] = row_item_list[i].strftime('%Y-%m-%d')
                         elif isinstance(row_item_list[i], time):
                             row_item_list[i] = row_item_list[i].strftime('%H:%M:%S')
+                        elif isinstance(row_item_list[i], str):
+                            row_item_list[i] = escape_csv(row_item_list[i])
                 csv_writer.writerow(row_item_list)
 
             # log an event
