@@ -18,7 +18,7 @@ from tendenci.libs.tinymce.widgets import TinyMCE
 from tendenci.apps.base.fields import EmailVerificationField, PriceField, CountrySelectField
 from tendenci.apps.base.forms import FormControlWidgetMixin
 from tendenci.apps.careers.models import Career
-from tendenci.apps.corporate_memberships.models import (CorpMembership, CorpMembershipAuthDomain,)
+from tendenci.apps.corporate_memberships.models import (CorpMembership, CorpMembershipAuthDomain, CorporateMembershipType)
 from tendenci.apps.educations.models import Education
 from tendenci.apps.entities.models import Entity
 from tendenci.apps.memberships.fields import (
@@ -44,6 +44,7 @@ from tendenci.apps.profiles.models import Profile
 from tendenci.apps.site_settings.utils import get_setting
 from tendenci.apps.base.utils import tcurrency
 from tendenci.apps.files.validators import FileValidator
+from tendenci.apps.emails.models import Email
 
 
 THIS_YEAR = datetime.today().year
@@ -304,6 +305,45 @@ class MembershipTypeForm(TendenciBaseForm):
         return super(MembershipTypeForm, self).save(*args, **kwargs)
 
 
+class MessageForm(FormControlWidgetMixin, forms.ModelForm):
+    recipient_type = forms.ChoiceField(
+        label=_("Recipients"),
+        initial='pending_members',
+        widget=forms.widgets.RadioSelect(),
+        choices=(
+            ('myself',_('Myself Only (for testing)')),
+            ('pending_members',_('Pending Members')),
+            ('pending_corp_members',_('Pending Corp Members')),
+            ),
+        help_text=_('Note that if "Myself Only" is selected, the view_link and edit_link will not be replaced if you\'re not a member.'))
+    subject = forms.CharField(widget=forms.TextInput(attrs={'style':'width:100%;padding:5px 0;'}))
+    body = forms.CharField(widget=TinyMCE(attrs={'style':'width:100%'},
+        mce_attrs={'storme_app_label':Email._meta.app_label,
+        'storme_model':Email._meta.model_name.lower()}),
+        label=_('Email Content'))
+    membership_type = forms.ModelChoiceField(label='',
+                                empty_label=_('All Membership Types'),
+                                required=False,
+                                queryset=MembershipType.objects.filter(status_detail='active'))
+    corpmembership_type = forms.ModelChoiceField(label='',
+                                empty_label=_('All Corporate Membership Types'),
+                                required=False,
+                                queryset=CorporateMembershipType.objects.filter(status_detail='active'))
+
+    class Meta:
+        model = Email
+        fields = ('subject', 'body',
+                  'sender_display',
+                  'reply_to',)
+
+    def __init__(self, *args, **kwargs):
+        super(MessageForm, self).__init__(*args, **kwargs)
+        if self.instance.id:
+            self.fields['body'].widget.mce_attrs['app_instance_id'] = self.instance.id
+        else:
+            self.fields['body'].widget.mce_attrs['app_instance_id'] = 0
+
+
 class MembershipDefaultUploadForm(forms.ModelForm):
     KEY_CHOICES = (
         ('username', 'username'),
@@ -1276,7 +1316,7 @@ class MembershipDefault2Form(FormControlWidgetMixin, forms.ModelForm):
             Membership.user
             Membership.user.profile
             Membership.invoice
-            Membership.user.group_set()
+            Membership.user.user_groups
         """
         user = kwargs.pop('user')
         request = kwargs.pop('request')
@@ -1899,7 +1939,7 @@ class MembershipDefaultForm(TendenciBaseForm):
             Membership.user.profile
             Membership.user.education
             Membership.invoice
-            Membership.user.group_set()
+            Membership.user.user_groups
         """
         request = kwargs.pop('request')
 
