@@ -1,13 +1,14 @@
 from django.contrib import admin
+from django.contrib.auth.models import Group as AuthGroup
 from django.utils.translation import ugettext_lazy as _
 
-from tendenci.apps.user_groups.models import Group, GroupMembership
+from tendenci.apps.user_groups.models import Group
 from tendenci.apps.user_groups.forms import GroupAdminForm
-from tendenci.core.perms.admin import TendenciBaseModelAdmin
+from tendenci.apps.perms.admin import TendenciBaseModelAdmin
 
 
 class GroupAdmin(TendenciBaseModelAdmin):
-    list_display = ['id', 'name', 'label', 'entity', 'dashboard_url', 'show_as_option', 'allow_self_add', 'allow_self_remove', 'admin_status']
+    list_display = ['name', 'label', 'entity', 'dashboard_url', 'show_as_option', 'allow_self_add', 'allow_self_remove', 'admin_status']
     search_fields = ['name', 'label', 'entity__entity_name']
     list_filter = ['entity', 'show_as_option', 'allow_self_add']
     list_editable = ['name', 'label', 'entity']
@@ -19,6 +20,7 @@ class GroupAdmin(TendenciBaseModelAdmin):
             'allow_anonymous_view', 'user_perms', 'member_perms', 'group_perms', 'status_detail')}),
     )
     form = GroupAdminForm
+    ordering = ("id",)
 
 #     def has_delete_permission(self, request, obj=None):
 #         if obj and obj.type == 'system_generated':
@@ -36,6 +38,5 @@ class GroupMembershipAdmin(admin.ModelAdmin):
 admin.site.register(Group, GroupAdmin)
 #admin.site.register(GroupMembership, GroupMembershipAdmin)
 
-from django.contrib.auth.models import Group as AuthGroup
 # unregister AuthGroup
 admin.site.unregister(AuthGroup)
